==> hboard-1.0-rc1.tar.gz: hboard/post_comment.php <==
<?php

/* EtchiBoard Version 1.0
     post_comment.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/message.inc"); // ޽ function

//  ó: ^^+
$name = str_replace("", " ", $name);
$name = trim($name);
$homepage = str_replace("", " ", $homepage);
$homepage = trim($homepage);
$email = str_replace("", " ", $email);
$email = trim($email);

if($name == "" || $icon == "" || $ne == "" || $passwd == "") {
 PrintHeader();
 PrintMessage("<b>Ͱ  ۵ ʾҽϴ.</b><br> ʿ  ͸  äּ.", "error");
 PrintFooter();
}

/*  ̶.. */
else {
 $article_no = $article; // ޽ function ..

 // Ű 
 setcookie("hboard10_name", $name, time() + 2592000);
 setcookie("hboard10_email", $email, time() + 2592000);
 setcookie("hboard10_homepage", $homepage, time() + 2592000);

 PrintHeader();

 if($homepage == "http://") {
  $homepage = ""; // http://  Ȩ 
 }

 $passwd = crypt($passwd, HB);
 $now_date = date("Y/m/d H:i:s");

 // ĿƮ ī б/
 
 $dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

 $indext = mysql_query("select reply from hboard_db_article where idx='$article'", $dbconnect);
 $cmtcount = mysql_result($indext, 0, "reply");
 $cmtcount++;
  mysql_query("update hboard_db_article set reply='$cmtcount' where idx='$article'",  $dbconnect);

 //  agent, IP ּ ϱ
 $user_agent = $_SERVER["HTTP_USER_AGENT"];
 $ip_addr = $_SERVER["REMOTE_ADDR"];

 // ̺ óڱ (hboard_db_comment)
  mysql_query("insert into hboard_db_comment values(\"$cmtcount\", \"$article\", \"$name\", \"$email\", \"$homepage\", \"$icon\", \"$ip_addr\", \"$passwd\", \"$now_date\", \"$ne\", \"f\", \"$user_agent\")");

  PrintMessage("${article} Խù ǰ ߰Ͽϴ.", "notice");
  mysql_close($dbconnect);

  PrintFooter();
}
?>

==> hboard-1.0.2.tar.gz: hboard/post_comment.php <==
<?php

/* EtchiBoard Version 1.0
     post_comment.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/message.inc"); // ޽ function

//  ó: ^^+
$name = str_replace("", " ", $name);
$name = trim($name);
$homepage = str_replace("", " ", $homepage);
$homepage = trim($homepage);
$email = str_replace("", " ", $email);
$email = trim($email);

if($name == "" || $icon == "" || $ne == "" || $passwd == "") {
 PrintHeader();
 PrintMessage("<b>Ͱ  ۵ ʾҽϴ.</b><br> ʿ  ͸  äּ.", "error");
 PrintFooter();
}

/*  ̶.. */
else {
 $article_no = $article; // ޽ function ..

 // Ű 
 setcookie("hboard10_name", $name, time() + 2592000);
 setcookie("hboard10_email", $email, time() + 2592000);
 setcookie("hboard10_homepage", $homepage, time() + 2592000);

 PrintHeader();

 if($homepage == "http://") {
  $homepage = ""; // http://  Ȩ 
 }

 $passwd = crypt($passwd, HB);
 $now_date = date("Y/m/d H:i:s");

 // ĿƮ ī б/
 
 $dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

 $indext = mysql_query("select reply from hboard_db_article where idx='$article'", $dbconnect);
 $cmtcount = mysql_result($indext, 0, "reply") or die(PrintMessage("ش Խù(${article}) ã  ϴ.<br>ش Խù ùٸ ϵǾ ִ Ȯ ּ.", "error"));
 $cmtcount++;
  mysql_query("update hboard_db_article set reply='$cmtcount' where idx='$article'",  $dbconnect);

 //  agent, IP ּ ϱ
 $user_agent = $_SERVER["HTTP_USER_AGENT"];
 $ip_addr = $_SERVER["REMOTE_ADDR"];

 // ̺ óڱ (hboard_db_comment)
  mysql_query("insert into hboard_db_comment values(\"$cmtcount\", \"$article\", \"$name\", \"$email\", \"$homepage\", \"$icon\", \"$ip_addr\", \"$passwd\", \"$now_date\", \"$ne\", \"f\", \"$user_agent\")");

  PrintMessage("${article} Խù ǰ ߰Ͽϴ.", "notice");
  mysql_close($dbconnect);

  PrintFooter();
}
?>
